==> adflow-react-native-sdk-1.0.3-beta.5.tgz: package/ios/FluentAdFlowWidgetViewManager.swift <==
import FluentAdFlowAdsWidget

@objc(FluentAdFlowWidgetViewManager)
class FluentAdFlowWidgetViewManager: RCTViewManager {
  var isListenerAdded = false;
  override func view() -> (FluentAdFlowWidget) {
      if(!isListenerAdded) {
          FluentAdFlowWidgetView.events.listenTo(eventName: "onAdFlowContainerClosed", action: onAdFlowContainerClosed)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onAdFlowContainerHeightChanged", action: onAdFlowContainerHeightChanged)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onAdFlowContainerShow", action: onAdFlowContainerShow)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onValidationFailed", action: onValidationFailed)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onError", action: onError)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onNotified", action: onNotified)
          isListenerAdded = true;
      }

      return FluentAdFlowWidget();
  }

  deinit {
      FluentAdFlowWidgetView.events.removeListeners(eventNameToRemoveOrNil: nil)
  }

  @objc override static func requiresMainQueueSetup() -> Bool {
    return false
  }
    
  func onAdFlowContainerClosed(data: Any?) {
    #if DEBUG
        print(">> onAdFlowContainerClosed -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onAdFlowContainerClosed", body: [data])
  }

  func onValidationFailed(data: Any?) {
    #if DEBUG
      print(">> onValidationFailed -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onValidationFailed", body: [data])
  }

  func onError(data: Any?) {
    #if DEBUG
      print(">> onError -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onError", body: [data])
  }

  func onAdFlowContainerShow(data: Any?) {
    #if DEBUG
      print(">> onAdFlowContainerShow -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onAdFlowContainerShow", body: [data])
  }

  func onAdFlowContainerHeightChanged(data: Any?) {
    #if DEBUG
      print(">> onAdFlowContainerHeightChanged -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onAdFlowContainerHeightChanged", body: [data])
  }

  func onNotified(data: Any?) {
    #if DEBUG
      print(">> onNotified -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onNotified", body: [data])
  }
}

class FluentAdFlowWidget : FluentAdFlowWidgetView {
  var _currentProps: [String]! = nil;
  required init?(apiKey: String, referer: String) {
    super.init(apiKey: apiKey, referer: referer)
  }

  required init(frame: CGRect){
    super.init(frame: frame)
  }
 
    required init(frame: CGRect, apiClient: ApiClientProtocol){
        fatalError("init(frame:apiClient:) has not been implemented")
    }

  required init?(coder aDecoder: NSCoder) {
    fatalError("init(coder:) has not been implemented")
  }

  override func didSetProps(_ changedProps: [String]!) {
    #if DEBUG
      print("changeProps: \(changedProps)")
    #endif
    
    if(_currentProps != changedProps && changedProps != ["height"]) {
      #if DEBUG
        print("****** Calling Update View ******")
      #endif
      super.updateView(changedProps)
      _currentProps = changedProps
    }    
  }
}

@objc(AdsViewEventEmitter)
open class AdsViewEventEmitter: RCTEventEmitter {

  public static var emitter: AdsViewEventEmitter!

  override init() {
    super.init()
    AdsViewEventEmitter.emitter = self
  }

  @objc
  override public func supportedEvents() -> [String] {
    ["onReady", "onPending", "onError", "onValidationFailed", "onAdFlowContainerClosed", "onAdFlowContainerShow", "onAdFlowContainerHeightChanged", "onNotified"] 
  }

  @objc override public static func requiresMainQueueSetup() -> Bool {
        return false
    }
}

==> adflow-react-native-sdk-1.0.6-beta.5.tgz: package/ios/FluentAdFlowWidgetViewManager.swift <==
import FluentAdFlowAdsWidget

@objc(FluentAdFlowWidgetViewManager)
class FluentAdFlowWidgetViewManager: RCTViewManager {
  var isListenerAdded = false;
  override func view() -> (FluentAdFlowWidget) {
      if(!isListenerAdded) {
          FluentAdFlowWidgetView.events.listenTo(eventName: "onAdFlowContainerClosed", action: onAdFlowContainerClosed)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onAdFlowContainerHeightChanged", action: onAdFlowContainerHeightChanged)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onAdFlowContainerShow", action: onAdFlowContainerShow)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onValidationFailed", action: onValidationFailed)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onError", action: onError)
          FluentAdFlowWidgetView.events.listenTo(eventName: "onNotified", action: onNotified)
          isListenerAdded = true;
      }

      return FluentAdFlowWidget();
  }

  deinit {
      FluentAdFlowWidgetView.events.removeListeners(eventNameToRemoveOrNil: nil)
  }

  @objc override static func requiresMainQueueSetup() -> Bool {
    return false
  }

  func onAdFlowContainerClosed(data: Any?, viewId: String?) {
    #if DEBUG
        print(">> onAdFlowContainerClosed -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onAdFlowContainerClosed", body: [viewId])
  }

  func onValidationFailed(data: Any?, viewId: String?) {
    #if DEBUG
      print(">> onValidationFailed -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onValidationFailed", body: [viewId])
  }

  func onError(data: Any?, viewId: String?) {
    #if DEBUG
      print(">> onError -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onError", body: [viewId])
  }

  func onAdFlowContainerShow(data: Any?, viewId: String?) {
    #if DEBUG
      print(">> onAdFlowContainerShow -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onAdFlowContainerShow", body: [viewId])
  }

  func onAdFlowContainerHeightChanged(data: Any?, viewId: String?) {
    #if DEBUG
      print(">> onAdFlowContainerHeightChanged -> \n\(data)")
    #endif
      var result = (viewId ?? "") + "$\(data as? CGFloat ?? 0.0)";
      print("result height: \(result)");
    AdsViewEventEmitter.emitter.sendEvent(withName: "onAdFlowContainerHeightChanged", body: result)
  }

  func onNotified(data: Any?, viewId: String?) {
    #if DEBUG
      print(">> onNotified -> \n\(data)")
    #endif
    AdsViewEventEmitter.emitter.sendEvent(withName: "onNotified", body: [viewId])
  }
}

class FluentAdFlowWidget : FluentAdFlowWidgetView {
  var _currentProps: [String]! = nil;
  required init?(apiKey: String, referer: String) {
    super.init(apiKey: apiKey, referer: referer)
  }

  required init(frame: CGRect){
    super.init(frame: frame)
  }

    required init(frame: CGRect, apiClient: ApiClientProtocol){
        fatalError("init(frame:apiClient:) has not been implemented")
    }

  required init?(coder aDecoder: NSCoder) {
    fatalError("init(coder:) has not been implemented")
  }

  override func didSetProps(_ changedProps: [String]!) {
    #if DEBUG
      print("changeProps: \(changedProps)")
    #endif

    if(_currentProps != changedProps && changedProps != ["height"]) {
      #if DEBUG
        print("****** Calling Update View ******")
      #endif
      super.updateView(changedProps)
      _currentProps = changedProps
    }
  }
}

@objc(AdsViewEventEmitter)
open class AdsViewEventEmitter: RCTEventEmitter {

  public static var emitter: AdsViewEventEmitter!

  override init() {
    super.init()
    AdsViewEventEmitter.emitter = self
  }

  @objc
  override public func supportedEvents() -> [String] {
    ["onReady", "onPending", "onError", "onValidationFailed", "onAdFlowContainerClosed", "onAdFlowContainerShow", "onAdFlowContainerHeightChanged", "onNotified"]
  }

  @objc override public static func requiresMainQueueSetup() -> Bool {
        return false
    }
}
